var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
/*
This file is part of the Notesnook project (https://notesnook.com/)

Copyright (C) 2023 Streetwriters (Private) Limited

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
import { Box, Flex, Text } from "@theme-ui/components";
import { useEffect, useRef } from "react";
import { Button } from "../../components/button";
import { useTimer } from "../../hooks/use-timer";
import { MathBlock } from "./math-block";
import { loadKatex } from "./plugin/renderers/katex";
export function MathBlockComponent(props) {
    var _a;
    const { editor, node, forwardRef, getPos } = props;
    const { indentLength, indentType, caretPosition } = node.attrs;
    const toolbarRef = useRef(null);
    const { enabled, start } = useTimer(1000);
    const isActive = editor.isActive(MathBlock.name);
    const elementRef = useRef(null);
    useEffect(() => {
        if (isActive)
            return;
        (function () {
            var _a;
            return __awaiter(this, void 0, void 0, function* () {
                const pos = getPos();
                const node = (_a = editor.current) === null || _a === void 0 ? void 0 : _a.state.doc.nodeAt(pos);
                const text = node === null || node === void 0 ? void 0 : node.textContent;
                if (text && elementRef.current) {
                    const katex = yield loadKatex();
                    elementRef.current.innerHTML = katex.renderToString(text, {
                        displayMode: true,
                        globalGroup: true,
                        throwOnError: false
                    });
                }
            });
        })();
    }, [isActive]);
    return (_jsxs(_Fragment, { children: [_jsxs(Flex, { sx: Object.assign({ flexDirection: "column", borderRadius: "default", overflow: "hidden" }, (isActive ? {} : { height: "1px", width: 0, visibility: "hidden" })), children: [_jsx(Text, { ref: forwardRef, as: "pre", autoCorrect: "off", autoCapitalize: "none", css: {}, sx: {
                            "div, span.token, span.line-number-widget, span.line-number::before": {
                                fontFamily: "monospace",
                                fontSize: "code",
                                whiteSpace: "pre",
                                tabSize: 1
                            },
                            position: "relative",
                            lineHeight: "20px",
                            bg: "codeBg",
                            color: "static",
                            overflowX: "auto",
                            display: "flex",
                            px: 2,
                            pt: 2,
                            pb: 2
                        }, spellCheck: false }), _jsxs(Flex, { ref: toolbarRef, contentEditable: false, sx: {
                            bg: "codeBg",
                            alignItems: "center",
                            justifyContent: "flex-end",
                            borderTop: "1px solid var(--codeBorder)"
                        }, children: [caretPosition ? (_jsxs(Text, { variant: "subBody", sx: { mr: 1, color: "codeFg" }, children: ["Line ", caretPosition.line, ", Column ", caretPosition.column, " ", caretPosition.selected
                                        ? `(${caretPosition.selected} selected)`
                                        : ""] })) : null, _jsx(Button, { variant: "icon", sx: {
                                    p: 1,
                                    opacity: "1 !important",
                                    ":hover": { bg: "codeSelection" }
                                }, title: "Toggle indentation mode", disabled: !editor.isEditable, onClick: () => {
                                    if (!editor.isEditable)
                                        return;
                                    editor.commands.changeCodeBlockIndentation({
                                        type: indentType === "space" ? "tab" : "space",
                                        amount: indentLength
                                    });
                                }, children: _jsxs(Text, { variant: "subBody", sx: { color: "codeFg" }, children: [indentType === "space" ? "Spaces" : "Tabs", ": ", indentLength] }) }), _jsx(Button, { variant: "icon", sx: {
                                    opacity: "1 !important",
                                    p: 1,
                                    bg: "transparent",
                                    ":hover": { bg: "codeSelection" }
                                }, disabled: true, children: _jsx(Text, { variant: "subBody", spellCheck: false, sx: { color: "codeFg" }, children: "Latex" }) }), ((_a = node.textContent) === null || _a === void 0 ? void 0 : _a.length) > 0 ? (_jsx(Button, { variant: "icon", sx: {
                                    opacity: "1 !important",
                                    p: 1,
                                    mr: 1,
                                    bg: "transparent",
                                    ":hover": { bg: "codeSelection" }
                                }, onClick: () => {
                                    editor.commands.copyToClipboard(node.textContent);
                                    start();
                                }, title: "Copy to clipboard", children: _jsx(Text, { variant: "subBody", spellCheck: false, sx: { color: "codeFg" }, children: enabled ? "Copied" : "Copy" }) })) : null] })] }), _jsx(Box, { contentEditable: false, ref: elementRef })] }));
}
