/*
This file is part of the Notesnook project (https://notesnook.com/)

Copyright (C) 2023 Streetwriters (Private) Limited

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
export function convertBrToParagraph(html) {
    const doc = new DOMParser().parseFromString(html, "text/html");
    for (const br of doc.querySelectorAll("br")) {
        const paragraph = br.closest("p");
        if (paragraph && paragraph.childNodes.length === 1)
            continue;
        if (paragraph) {
            splitOn(paragraph, br);
            const children = Array.from(paragraph.childNodes.values());
            const newParagraph = doc.createElement("p");
            newParagraph.dataset.spacing = "single";
            paragraph.dataset.spacing = "single";
            newParagraph.append(...children.slice(children.indexOf(br) + 1));
            paragraph.insertAdjacentElement("afterend", newParagraph);
            br.remove();
        }
    }
    return doc;
}
function splitOn(bound, cutElement) {
    let grandparent = null;
    for (let parent = cutElement.parentNode; bound != parent; parent = grandparent) {
        if (parent) {
            const right = parent.cloneNode(false);
            while (cutElement.nextSibling)
                right.appendChild(cutElement.nextSibling);
            grandparent = parent.parentNode;
            grandparent === null || grandparent === void 0 ? void 0 : grandparent.insertBefore(right, parent.nextSibling);
            grandparent === null || grandparent === void 0 ? void 0 : grandparent.insertBefore(cutElement, right);
        }
    }
}
